const regFileExtension = /(?:\.([^.]+))?$/;

export class FileUtil {
  static getExtension(fileName: string): string | undefined {
    return regFileExtension.exec(fileName)[1];
  }

  static getExtensions(fileList: FileList): string[] {
    const extensions: string[] = [];
    // tslint:disable-next-line: prefer-for-of
    for (let i = 0; i < fileList.length; i++) {
      extensions.push(FileUtil.getExtension(fileList[i].name));
    }
    return extensions;
  }

  static toDataUrl(blob: Blob): Promise<string | ArrayBuffer> {
    return new Promise<string | ArrayBuffer>((resolve, reject) => {
      const fileReader = new FileReader();
      fileReader.readAsDataURL(blob);

      fileReader.onload = () => {
        return resolve(fileReader.result);
      };
      fileReader.onerror = (event: ProgressEvent) => {
        fileReader.abort();
        return reject(fileReader.error);
      };
    });
  }
}
